@@ -1,5 +1,6 @@
 import os
 import shutil
+from .pure import version
 # --- 初始化环境 ---
 
 
@@ -20,7 +21,7 @@ def run():
     if os.path.exists(dst1) and os.path.exists(dst):
         return
 
-    print('--- 首次引入bddjango, 初始化templates中...')
+    print(f'--- 首次引入bddjango v{version()}, 初始化templates文件夹.')
     create_dir_if_not_exist('templates')
     create_dir_if_not_exist(os.path.join('templates', 'admin'))
     create_dir_if_not_exist(os.path.join('templates', 'entities'))
